pynrc.obs_hci
======================

.. currentmodule:: pynrc

.. autoclass:: obs_hci
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~obs_hci.planets
      ~obs_hci.wfe_ref_drift

   .. rubric:: Methods Summary

   .. autosummary::

      ~obs_hci.add_planet
      ~obs_hci.kill_planets
      ~obs_hci.calc_contrast
      ~obs_hci.gen_offset_psf
      ~obs_hci.gen_disk_image
      ~obs_hci.gen_planets_image
      ~obs_hci.gen_roll_image
      ~obs_hci.planet_spec
      ~obs_hci.saturation_levels
      ~obs_hci.star_flux

   .. rubric:: Methods Documentation

   .. automethod:: add_planet
   .. automethod:: kill_planets
   .. automethod:: calc_contrast
   .. automethod:: gen_offset_psf
   .. automethod:: gen_disk_image
   .. automethod:: gen_planets_image
   .. automethod:: gen_roll_image
   .. automethod:: planet_spec
   .. automethod:: saturation_levels
   .. automethod:: star_flux
